<?php

namespace SGalinski\SgNews\ViewHelpers;

/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (https://www.sgalinski.de)
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use TYPO3\CMS\Extbase\Object\ObjectManager;
use TYPO3Fluid\Fluid\Core\ViewHelper\AbstractViewHelper;
use TYPO3\CMS\Frontend\ContentObject\ContentObjectRenderer;

/**
 * View helper that renders a page browser based upon the pagebrowse extension.
 *
 * Example:
 * {namespace sg=SGalinski\SgNews\ViewHelpers}
 * <sg:pageBrowser numberOfPages="" />
 */
class PageBrowserViewHelper extends AbstractViewHelper {
	/**
	 * Specifies whether the escaping interceptors should be disabled or enabled for the render-result of this ViewHelper
	 *
	 * @see isOutputEscapingEnabled()
	 *
	 * @var boolean
	 */
	protected $escapeOutput = FALSE;

	/**
	 * @var ObjectManager
	 */
	protected $objectManager;

	/**
	 * Inject the ObjectManager
	 *
	 * @param ObjectManager $objectManager
	 */
	public function injectObjectManager(ObjectManager $objectManager) {
		$this->objectManager = $objectManager;
	}

	/**
	 * Initialize the ViewHelpers arguments
	 */
	public function initializeArguments() {
		parent::initializeArguments();
		$this->registerArgument('numberOfPages', 'int', 'The number of pages to browse', TRUE);
	}

	/**
	 * Render method of the view helper.
	 *
	 * @return string
	 * @throws \UnexpectedValueException
	 */
	public function render(): string {
		$numberOfPages = $this->arguments['numberOfPages'];
		$configuration = $GLOBALS['TSFE']->tmpl->setup['plugin.']['tx_sgnews.']['pagebrowser.'];
		$configuration['settings.']['numberOfPages'] = (int) $numberOfPages;

		/** @var ContentObjectRenderer $contentObject */
		$contentObject = $this->objectManager->get(ContentObjectRenderer::class);
		$contentObject->start([]);
		return $contentObject->cObjGetSingle('USER', $configuration);
	}
}
